<template>
    <div class="report-overview">
        <div class="search-box">
            项目分类：
            <dict-select :popperClass="`big-search-popper`" dictCode="sgyp-xmfl" :hasDefaultOption="true" clearable v-model="projectCategory"
                        style="width: 350px;" placeholder="请选择所项目分类" @input="() =>getData()"/>
        </div>
        <el-table height="calc(100% - 50px)" :element-loading-background="loadingColor" v-loading="loading" align="center"
            :data="tableData" id="table-bigger-detail" class="dialog_table" ref="myTable" highlight-current-row
            :header-cell-style="{ 'text-align': 'center' }">
            <el-table-column type="index" label="序号" width="60" align="center">
            </el-table-column>
            <el-table-column prop="projectName" label="项目名称" align="left">
            </el-table-column>
            <el-table-column prop="unitName" label="主责单位" width="120" align="center">
            </el-table-column>
            <el-table-column prop="groupName" label="专项小组" align="center" width="140">
                <!-- <template v-slot="{ row }">
                    {{ row.groupName.slice(0, row.groupName.length - 6) }}
                </template> -->
            </el-table-column>
            <el-table-column prop="groupName" label="项目进度" align="center" width="220">
                <template v-slot="{ row }">
                    <div class="progress">
                        <el-progress class="first-progress" :percentage="row.progressUnFinishRate || 0" color="#d22a1f">
                        </el-progress>
                        <el-progress :text-inside="row.progressFinishRate > 29"
                            :percentage="row.progressFinishRate || 0" color="#67c23a">
                        </el-progress>
                    </div>
                    <!-- <div class="progress-box">
                        <div class="progress">
                            <el-progress class="first-progress" :percentage="row.progressUnFinishRate || 0"
                                color="#d22a1f">
                            </el-progress>
                            <el-progress :percentage="row.progressFinishRate || 0" color="#67c23a">
                            </el-progress>
                        </div>
                        <div class="progress-value">{{ row.progressFinishRate || 0 }}%</div>
                    </div> -->
                </template>
            </el-table-column>
            <el-table-column prop="target1" :label="`组建\n工作专班`" width="120" align="center">
                <template v-slot="{ row }">
                    <div :style="`${setStyle(row.target1.statusText, row)}`" @click="openDetails(row, 1)">
                        {{ row.target1.statusText }}
                    </div>
                </template>
            </el-table-column>
            <el-table-column prop="target2" :label="`开展\n调查研究`" width="120" align="center">
                <template v-slot="{ row }">
                    <div :style="`${setStyle(row.target2.statusText, row)}`" @click="openDetails(row, 2)">
                        {{ row.target2.statusText }}
                    </div>
                </template>
            </el-table-column>
            <el-table-column prop="target3" :label="`制定\n改革方案`" width="120" align="center">
                <template v-slot="{ row }">
                    <div :style="`${setStyle(row.target3.statusText, row)}`" @click="openDetails(row, 3)">
                        {{ row.target3.statusText }}
                    </div>
                </template>
            </el-table-column>
            <el-table-column prop="target4" :label="`出台\n配套政策`" width="120" align="center">
                <template v-slot="{ row }">
                    <div :style="`${setStyle(row.target4.statusText, row)}`" @click="openDetails(row, 4)">
                        {{ row.target4.statusText }}
                    </div>
                </template>
            </el-table-column>
            <el-table-column prop="target5" :label="`向上\n争取支持`" width="120" align="center">
                <template v-slot="{ row }">
                    <div :style="`${setStyle(row.target5.statusText, row)}`" @click="openDetails(row, 5)">
                        {{ row.target5.statusText }}
                    </div>
                </template>
            </el-table-column>
            <el-table-column prop="target6" :label="`开展\n试点示范`" width="120" align="center">
                <template v-slot="{ row }">
                    <div :style="`${setStyle(row.target6.statusText, row)}`" @click="openDetails(row, 6)">
                        {{ row.target6.statusText }}
                    </div>
                </template>
            </el-table-column>
            <el-table-column prop="target7" :label="`上线\n重大应用`" width="120" align="center">
                <template v-slot="{ row }">
                    <div :style="`${setStyle(row.target7.statusText, row)}`" @click="openDetails(row, 7)">
                        {{ row.target7.statusText }}
                    </div>
                </template>
            </el-table-column>
            <el-table-column prop="target8" :label="`开展\n督导指导`" width="120" align="center">
                <template v-slot="{ row }">
                    <div :style="`${setStyle(row.target8.statusText, row)}`" @click="openDetails(row, 8)">
                        {{ row.target8.statusText }}
                    </div>
                </template>
            </el-table-column>
            <el-table-column prop="target9" :label="`总结\n推广经验`" width="120" align="center">
                <template v-slot="{ row }">
                    <div :style="`${setStyle(row.target9.statusText, row)}`" style="margin-right: 10px;"
                        @click="openDetails(row, 9)">
                        {{ row.target9.statusText }}
                    </div>
                </template>
            </el-table-column>
        </el-table>
        <monthlyProgressDialog ref="monthlyProgressDialog"></monthlyProgressDialog>
        <!-- <div class="tips">
            备注：①绿色为已完成事项；②蓝色为推进中事项；③红色为未完成事项； ④灰色为未启动事项；⑤“/”为暂不涉及事项。
        </div> -->
    </div>
</template>
<script>
import apiList from '@/api/bigScreen/majorView.js'
import monthlyProgressDialog from './monthlyProgressDialog.vue'
import ExcelJS from 'exceljs';
export default {
    projectName: 'reportOverview',
    components: {
        monthlyProgressDialog
    },
    props: {
        tableOptions: {
            type: Object,
            default: () => {
                return {}
            },
        },
    },
    data() {
        return {
            loading: false,
            loadingColor: 'rgba(7, 45, 98,.4)',
            dataReady: false,
            tableData: [],
            planTypeDetails: [],
            workbook: null,
            projectName: '',
            projectCategory: ''
        }
    },
    mounted() {
        this.getData()
        this.$bus.$on('changeDate', (searchDate) => {
            this.getData()
        })
        this.$bus.$on('monthExportExcel', (comp) => {
            if (comp === 'projectStatementDetail') {
                this.clickExport()
            }
        })
    },
    created() {
        this.projectName = this.$route.query.projectName || ''
        this.$emit('searchDateChange')
    },
    methods: {
        openDetails(item, index) {
            let { statusText } = item[`target${index}`]
            if (statusText === '不涉及') {
                this.$message.warning('暂无涉及数据')
            } else {
                this.$refs.monthlyProgressDialog.open(item, index)
            }
        },
        getData() {
            this.loading = true
            this.tableData = []
            let data = JSON.parse(sessionStorage.getItem('searchDate'))
            data.projectCategory = this.projectCategory
            apiList.getAccelerateImplementationDetails(data, (res) => {
                if (res.data) {
                    let data = JSON.parse(JSON.stringify(res.data))
                    data.forEach(item => {
                        item.unitName = item.statusVoList[0].unitName
                        item.progressFinishRate = item.progressFinishRate ? item.progressFinishRate : 0
                        item.progressUnFinishRate = (item.progressUnFinishRate ? item.progressUnFinishRate : 0) + item.progressFinishRate
                        if (item.statusVoList) {
                            item.statusVoList.forEach(eml => {
                                eml.planType === 1 ? item.target1 = eml :
                                    eml.planType === 2 ? item.target2 = eml :
                                        eml.planType === 4 ? item.target3 = eml :
                                            eml.planType === 5 ? item.target4 = eml :
                                                eml.planType === 3 ? item.target5 = eml :
                                                    eml.planType === 12 ? item.target6 = eml :
                                                        eml.planType === 7 ? item.target7 = eml :
                                                            eml.planType === 8 ? item.target8 = eml :
                                                                eml.planType === 10 ? item.target9 = eml : ''
                            })
                        }
                    });
                    this.tableData = data
                    this.$nextTick(() => {
                        this.tableData.forEach((item, index) => {
                            if (item.projectName === this.projectName) {
                                this.$refs.myTable.setCurrentRow(item)
                                let highlightLines = this.$refs.myTable.$el.querySelectorAll('.el-table__body tbody .el-table__row')
                                let scrollTop = 0
                                for (let i = 0; i < highlightLines.length; i++) {
                                    if (i === (index)) {
                                        break
                                    }
                                    scrollTop += highlightLines[i].offsetHeight
                                }
                                this.$refs.myTable.bodyWrapper.scrollTop = scrollTop
                            }
                        })
                    })
                    this.exportToExcel()
                }
                this.loading = false
            })
        },

        setStyle(value, row) {

            // 'background:#a0a0a0;color:#333;font-weight:900;font-size: 24px;' : 'display: none;'
            let style = (value.indexOf('已完成') !== -1 || value.indexOf('年实施') !== -1)
                ? 'background :#38a846;font-weight: bold;'
                : value.indexOf('推进中') !== -1
                    ? 'background:#00b0f0;font-weight: bold;'
                    : value.indexOf('未启动') !== -1
                        ? 'background:rgba(232, 232, 232, .85);font-weight: bold;'
                        : value.indexOf('未完成') !== -1
                            ? 'background:#f43308;font-weight: bold;'
                            : value.indexOf('不涉及') !== -1 ?
                                'background:#a0a0a0;font-weight: bold;color:#fff' : ''

            return style + 'user-select:none;color:#383838;'
        },
        exportToExcel() {
            let columns = [
                { title: '项目名称', dataIndex: 'projectName' },
                { title: '主责单位', dataIndex: 'unitName' },
                { title: '专项小组', dataIndex: 'groupName' },
                { title: '项目进度', dataIndex: 'progressFinishRate' },
                { title: '组建\n工作专班', dataIndex: "target1" },
                { title: '开展\n调查研究', dataIndex: "target2" },
                { title: '制定\n改革方案', dataIndex: "target3" },
                { title: '出台\n配套政策', dataIndex: "target4" },
                { title: '向上\n争取支持', dataIndex: "target5" },
                { title: '开展\n试点示范', dataIndex: "target6" },
                { title: '上线\n重大应用', dataIndex: "target7" },
                { title: '开展\n督导指导', dataIndex: "target8" },
                { title: '总结\n推广经验', dataIndex: "target9" },
            ]

            const workbook = new ExcelJS.Workbook();
            const worksheet = workbook.addWorksheet('Sheet1');

            const data = JSON.parse(JSON.stringify(this.tableData))

            const headerRow = worksheet.addRow(columns.map(column => column.title));
            headerRow.eachCell((cell) => {
                cell.font = { bold: true, size: 14 };
                cell.alignment = {
                    horizontal: "center",// 水平居中
                    vertical: 'middle', // 垂直居中
                };
                cell.border = {
                    top: { style: 'thin' },
                    left: { style: 'thin' },
                    bottom: { style: 'thin' },
                    right: { style: 'thin' }
                };
                cell.alignment = {
                    wrapText: true,
                    vertical: 'middle',
                    horizontal: 'center'
                }
            });

            data.forEach((rowData) => {
                const newRow = worksheet.addRow(columns.map((column) => {
                    if (column.title === '项目进度') {
                        console.log(rowData);

                        return rowData[column.dataIndex] + '%' || ""
                    }
                    if (column.dataIndex.indexOf('target') !== -1) {
                        return rowData[column.dataIndex].statusText || ""
                    } else {
                        return rowData[column.dataIndex] || ""
                    }
                }));
                newRow.eachCell((cell, rowNum) => {
                    cell.border = {
                        top: { style: 'thin' },
                        left: { style: 'thin' },
                        bottom: { style: 'thin' },
                        right: { style: 'thin' }
                    };
                    cell.alignment = {
                        wrapText: true
                    }
                    if (rowNum > 3) {
                        cell.fill = returnColor(cell.value)
                    }
                    cell.alignment.vertical = 'middle'
                    cell.alignment.horizontal = 'center'
                })
            });

            const columnWidths = {
                A: 32,
                B: 13,
                C: 15,
                D: 15,
                E: 15,
                F: 15,
                G: 15,
                H: 15,
                I: 15,
                J: 15,
                K: 15,
                L: 15,
                M: 15,
            };
            Object.keys(columnWidths).forEach((columnLetter) => {
                worksheet.getColumn(columnLetter).width = columnWidths[columnLetter];
            });

            function returnColor(value) {
                let argb = (value.indexOf('已完成') !== -1 || value.indexOf('年实施') !== -1)
                    ? '38a846'
                    : value.indexOf('推进中') !== -1 ? '00b0f0'
                        : value.indexOf('未启动') !== -1 ? 'e8e8e8'
                            : value.indexOf('未完成') !== -1 ? 'f43308'
                                : value.indexOf('不涉及') !== -1 ? 'a0a0a0' : ''
                return {
                    type: 'pattern',
                    pattern: 'solid',
                    fgColor: { argb }
                }
            }

            this.workbook = workbook
        },
        clickExport() {
            this.workbook.xlsx.writeBuffer().then((buffer) => {
                const blob = new Blob([buffer], { type: 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet' });
                const url = window.URL.createObjectURL(blob);
                const a = document.createElement('a');
                a.href = url;
                a.download = '月度计划进展.xlsx';
                a.click();
                window.URL.revokeObjectURL(url);
            });
        }
    },
}
</script>
<style lang="scss" scoped>
/deep/.el-input__inner {
    color: #fff;
    font-size: 18PX;
    height: 40PX;
    box-sizing: border-box;
    background: transparent;
    border: 1px solid #114385;

    &::placeholder {
        color: #fff;
        font-size: 18PX !important;
    }

    &::-webkit-input-placeholder {
        font-size: 18PX !important;
    }
}
.progress {
    position: relative;
    height: 50PX;
    padding: 0 !important;

    /deep/.el-progress {
        position: absolute;
        left: 0;
        top: 50%;
        width: 100%;
        padding: 0 !important;
        transform: translateY(-50%);

        .el-progress-bar {
            padding: 0 !important;
            margin-right: 0;
        }

        .el-progress-bar__outer {
            height: 20PX !important;
            padding: 0 !important;
            border-radius: 5PX;
            background: transparent;

            .el-progress-bar__inner {
                border-radius: 5PX;
            }
        }

        .el-progress__text {
            position: absolute;
            right: 5px;
            top: 50%;
            transform: translateY(-49.98%);
            height: 20PX;
            padding: 0 !important;
            line-height: 20PX;
            font-size: 18PX !important;
            color: #fff;
            letter-spacing: 1.5px;
        }

        .el-progress-bar__innerText {
            position: absolute;
            right: 0;
            top: 0;
            height: 20PX;
            padding: 0 !important;
            line-height: 20PX;
            font-size: 18PX !important;
            color: #fff;
        }
    }

    .first-progress {
        /deep/.el-progress-bar__outer {
            background-color: #0045bd;
        }

        /deep/.el-progress__text {
            display: none;
        }
    }
}


// .progress-box {
//     display: flex;
//     justify-content: space-between;
//     align-items: center;
//     flex-wrap: nowrap;
//     gap: 10px;

//     .progress {
//         position: relative;
//         width: 70%;
//         height: 50px;

//         /deep/.el-progress {
//             position: absolute;
//             left: 0;
//             top: 50%;
//             width: 100%;
//             transform: translateY(-50%);

//             .el-progress-bar {
//                 margin-right: 0;
//             }

//             .el-progress-bar__outer {
//                 height: 10px !important;
//                 padding: 0 !important;
//                 border-radius: 0;
//                 background: transparent;

//                 .el-progress-bar__inner {
//                     border-radius: 0;
//                 }
//             }

//             .el-progress__text {
//                 display: none;
//             }
//         }

//         .first-progress {
//             /deep/.el-progress-bar__outer {
//                 background-color: #0045bd;
//             }
//         }
//     }

//     .progress-value {
//         width: 30%;
//         font-size: 18PX;
//         color: #0058ef;
//         text-align: right;
//     }
// }

/deep/#table-bigger-detail th {
    .cell {
        line-height: 22PX;
    }
}

/deep/#table-bigger-detail .el-table--border th,
/deep/.el-table--border td {
    // color: #383838;
    border-right: 1PX solid rgb(39, 86, 162) !important;
}

/deep/#table-bigger-detail.el-table th.el-table__cell.is-leaf,
/deep/#table-bigger-detail.el-table td.el-table__cell {
    border-bottom: 1PX solid rgb(39, 86, 162) !important;
}

/deep/.el-table__body tr.current-row>td.el-table__cell {
    background-color: #114385 !important;
}

/deep/#table-bigger-detail.dialog_table.el-table {
    thead tr {
        background: none !important;
    }

    thead tr,
    thead tr th {
        background: none !important;
        background-color: #114385 !important;
        color: #FFFFFF;
    }

    th>.cell {
        font-size: 18PX;
        font-family: SimHei;
        font-weight: bold;
        color: #FFFFFF;
    }

    td>.cell {
        color: #FFFFFF !important;
        font-size: 18PX;
        line-height: 145%;

        div {
            padding: 10PX 0;
            font-size: 18PX;
        }
    }
}

/deep/#table-bigger-detail.el-table--border {
    border: 1PX solid rgb(39, 86, 162) !important;

    .el-table__cell {
        border-right: 1PX solid rgb(39, 86, 162) !important;
    }

    th.el-table__cell {
        border-bottom: 1PX solid rgb(39, 86, 162) !important;
    }

    td {
        border-right: 1PX solid rgb(39, 86, 162) !important;
    }

    th {
        border-right: 1PX solid rgb(39, 86, 162) !important;
    }
}

/deep/#table-bigger-detail.el-table {
    background-color: transparent;

    tr {
        background-color: rgba(1, 39, 101, 1) !important;
        color: #FFFFFF !important;
    }
}


// #table-bigger-detail .el-table--enable-row-hover .el-table__body tr:hover > td.el-table__cell {
//     background-color: rgba(2, 115, 233, 0.3)!important;
// }
/deep/#table-bigger-detail.el-table tbody tr:hover>td {
    background-color: rgba(2, 115, 233, 0.3) !important;
}

/deep/#table-bigger-detail.el-table--group::after,
/deep/#table-bigger-detail.el-table--border::after,
/deep/#table-bigger-detail.el-table::before {
    background-color: #001f47 !important;
}

/deep/#table-bigger-detail.el-table th.el-table__cell>.cell {
    white-space: pre;

}

/deep/#table-bigger-detail {

    /* 设置滚动条的样式 */
    ::-webkit-scrollbar {
        width: 18px !important; //垂直方向上的宽
        height: 8PX !important; //水平方向上的宽
    }

    /* 滚动槽 */
    ::-webkit-scrollbar-track {
        border-radius: 0 !important;
        background-color: #01215a !important;
    }

    /* 滚动条滑块 */
    ::-webkit-scrollbar-thumb {
        border-radius: 12PX;
        background-color: #034eb0 !important;
    }

    /*滚动条交叉样式*/
    ::-webkit-scrollbar-corner {
        background: #01215a !important;
    }
}

.tips {
    font-size: 18PX;
    margin-top: 10px;
}
</style>
<style lang="scss" scoped>
.report-overview {
    height: 100%;
    margin-top: 5PX;

    .search-box {
        height: 40PX;
        line-height: 40PX;
        font-size: 18PX;
        margin-bottom: 10PX;
    }
}

/deep/.dialog_table.el-table {
    th>.cell {
        font-size: 18PX !important;
    }
}
</style>
